//****************************************************
//*
//*  Dummy UserAnalysis Script to be used with gui.C 
//*  Functions in this scripts are called by GUIMainMacro.C  
//*  
//*  In this script, global functions, UserInitialize() nad UserAnalysis()
//*  Must be defined.  UserInitialize() is called at job initialization 
//*  to initialize histograms, etc.  It is also called when reset historgam
//*  menu is selected from JSF Control Panel.  UserAnalysis() is called 
//*  during the event loop after executing Process functions of JSF modules
//*  and display event daia but before display histogram.  See GetEvent()
//*  function in GUIMainMacro.C, where UserAnalysis() is called.
//*
//*  UserSetOptions() and UserTerminate() may be defined in this file.
//*  UserSetOptions() are called before declaration of JSF modules.
//*  It can be used to set parameters optional for user analsis.
//*  UserTerminate() is called during the JSF termination process.
//*
//*  When runmode=4, UserModuleDefine() must be defined in this file.
//*  It is used to define JSF modules specific to user analysis.  
//*  
//*$Id: UserAnalysis.C,v 1.2 1999/08/30 08:37:59 miyamoto Exp $
//*
//****************************************************

TH1F *hNumJets;
TH1F *hYmax;
TH1F *hEJet;
TCanvas *cHist;
//_________________________________________________________
void UserInitialize()
{
  //  This function is called at the begining of the job or when
  //  "reset hist" action is selected in the gui menu.
  //  This is used to define/reset histograms.

  cHist=new TCanvas("cHist","Canvas 1",100, 100, 400, 400);
  cHist->Divide(2,2);
  hNumJets=new TH1F("hNumJets","Numer of jets",50, 0.0, 50.0);
  hYmax=new TH1F("hYmax","Ymax",100, 0.0, 1.0);
  hEJet=new TH1F("hEJet", "Jet Energy", 100, 0.0, 300.0);

}

//_________________________________________________________
void UserAnalysis()
{

  Int_t nevt=jsf->GetEventNumber();
  if( nevt%100 == 1 ) {
    cout << "Event #=" << nevt << endl;
  }

  JSFQuickSim *sim=jsf->FindModule("JSFQuickSim");
  JSFQuickSimBuf *sbuf=(JSFQuickSimBuf*)sim->EventBuf();

  //
  TClonesArray *trks=sbuf->GetTracks();
  ANL4DVector  sum;
  TObjArray    particles(1000);

  Int_t ntracks=0;
  Int_t nc=0;
  TIter next(trks);
  JSFLTKCLTrack *t;
  while((t=(JSFLTKCLTrack*)next())) {
    Double_t pe=TMath::Sqrt(t->GetPx()*t->GetPx() + t->GetPy()*t->GetPy()
			  + t->GetPz()*t->GetPz() + 0.134*0.134 );
    ANL4DVector *p=new  ANL4DVector(pe, t->GetPx(), t->GetPy(), t->GetPz());
    particles.Add(p);
    
    sum+=(*p);   // Sum 4 momentum of all particles
  }
 
  //
  Double_t ycut=0.00001;
  if( particles.GetEntries() > 4 ) {
    ANLJetFinder *finder=new ANLJadeJetFinder(ycut);
    finder->Initialize(particles);
    finder->FindJets();
    Int_t njets=finder->GetNjets();
    hNumJets->Fill((Double_t)njets);
    
    if( njets > 3 ) {
      finder->ForceNJets(4);   // Forced 4 jets analysis
      hYmax->Fill(finder->GetYmax());
      TObjArray &jets=finder->GetJets();  // jet collection
      TIter nextjet(&jets);
      ANLJet *jetp;
      while( (jetp=(ANLJet*)nextjet()) ) {
	hEJet->Fill(jetp->E());     // Histogram jet energy
      }
    }

  }

  particles.Delete();  // Delete p objects in particles
}

//_________________________________________________________
void DrawHist()
{
  //  This function is called to draw histograms during the interactive 
  //  session.  Thus you can see the accumulation of the histogram
  //  interactively.  

  TDirectory *old=gDirectory;
  cHist->cd(1) ; hNumJets->Draw();
  cHist->cd(2) ; hYmax->Draw();
  cHist->cd(3) ; hEJet->Draw();
  cHist->Modified();
  cHist->Update();

  old->cd();

}





