//
//  hist2: complicated version of hist1 using
//    (1) TText
//    (2) TH1::GetNbinsX() and TH1::GetBinContent()
//    (3) Using various option for Draw.
//    (4) Write string using sprintf(...)
//

Int_t hist2()
{
  TCanvas *c1=new TCanvas("c1","Dynamic Filling Example",200,10,700,500);

  TH1F *hpx = new TH1F("hpx","This is first hist",40, -4, 4); 
  TText *text=new TText();

  hpx->SetFillColor(48);
  Double_t px=0.0;
  Double_t mean=0.0;
  Double_t sigma=1.0;
  const Int_t kUPDATE = 1000;

  Int_t  iopt=0;
  const  Int_t maxopt=13;
  Char_t opt[maxopt][4]={"AH","B","C","E","E0","E1","E2","E3","E4","L","P","P0","*H"};

  Int_t  center_bin=hpx->GetNbinsX()/2;
  Char_t message[64];

  for(Int_t i=0 ; i<25000 ; i++) {
    px=gRandom->Gaus(mean, sigma);
    hpx->Fill(px);
    if( i%kUPDATE == 0 ) {
      hpx->Draw(&opt[iopt][0]);        // Draw Histogram
      Double_t ypos=hpx->GetBinContent(center_bin); // Get bin content of center bin.

      sprintf(message,"Draw option = %s",&opt[iopt][0]);
      text->DrawText(-3.5, ypos, message);

      c1->Modified();
      c1->Update();                    // Update Canvas
      iopt = iopt < maxopt-1 ? iopt+1 : 0 ;  
      gSystem->Sleep(2000);            // Sleep 2 sec
    }
  }

}

/*
Draw options : see http://root.cern.ch/root/html304/THistPainter.html#THistPainter:Paint

   "AH"     : Draw histogram, but not the axis labels and tick marks
    "B"      : Bar chart option
    "C"      : Draw a smooth Curve througth the histogram bins
    "E"      : Draw error bars
    "E0"     : Draw error bars including bins with o contents
    "E1"     : Draw error bars with perpendicular lines at the edges
    "E2"     : Draw error bars with rectangles
    "E3"     : Draw a fill area througth the end points of the vertical error bars
    "E4"     : Draw a smoothed filled area through the end points of the error bars
    "L"      : Draw a line througth the bin contents
    "P"      : Draw current marker at each bin except empty bins
    "P0"     : Draw current marker at each bin including empty bins
    "*H"     : Draw histogram with a * at each bin
    "LF2"    : Draw histogram like with option "L" but with a fill area.
             : Note that "L" draws also a fill area if the hist fillcolor is set
             : but the fill area corresponds to the histogram contour.
    "9"      : Force histogram to be drawn in high resolution mode.
             : By default, the histogram is drawn in low resolution
             : in case the number of bins is greater than the number of pixels
             : in the current pad.
*/


